summaryrefslogtreecommitdiffstats
path: root/src/server/events/DisconnectAll.hpp
diff options
context:
space:
mode:
authorDavid Robillard <d@drobilla.net>2012-08-18 23:05:06 +0000
committerDavid Robillard <d@drobilla.net>2012-08-18 23:05:06 +0000
commit317627ef40f7654c298aa1ac707851c852259e3a (patch)
tree38f7ed57aafb7b3b8e21e6caa3429a39207e4a9a /src/server/events/DisconnectAll.hpp
parent160b2baf7df8b960f22619c013b3197c0dc51c2b (diff)
downloadingen-317627ef40f7654c298aa1ac707851c852259e3a.tar.gz
ingen-317627ef40f7654c298aa1ac707851c852259e3a.tar.bz2
ingen-317627ef40f7654c298aa1ac707851c852259e3a.zip
Node => Block
git-svn-id: http://svn.drobilla.net/lad/trunk/ingen@4720 a436a847-0d15-0410-975c-d299462d15a1
Diffstat (limited to 'src/server/events/DisconnectAll.hpp')
-rw-r--r--src/server/events/DisconnectAll.hpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/server/events/DisconnectAll.hpp b/src/server/events/DisconnectAll.hpp
index 12c04ffa..68ba8ebe 100644
--- a/src/server/events/DisconnectAll.hpp
+++ b/src/server/events/DisconnectAll.hpp
@@ -27,8 +27,8 @@
namespace Ingen {
namespace Server {
+class BlockImpl;
class CompiledPatch;
-class NodeImpl;
class PatchImpl;
class PortImpl;
@@ -36,7 +36,7 @@ namespace Events {
class Disconnect;
/** An event to disconnect all connections to a Node.
*
* \ingroup engine
*/
@@ -66,7 +66,7 @@ private:
Raul::Path _parent_path;
Raul::Path _path;
PatchImpl* _parent;
- NodeImpl* _node;
+ BlockImpl* _block;
PortImpl* _port;
Impls _impls;
CompiledPatch* _compiled_patch;
@@ -36,7 +36,7 @@ namespace Events {
class Disconnect;
-/** An event to disconnect all connections to a Node.
+/** An event to disconnect all connections to a Block.
*
* \ingroup engine